Documentation
¶
Index ¶
- Variables
- type AddCheckConfigurationArgs
- type ApprovalCheckConfiguration
- type CheckConfiguration
- type CheckConfigurationData
- type CheckConfigurationExpandParameter
- type CheckConfigurationRef
- type CheckData
- type CheckDefinitionData
- type CheckIcon
- type CheckRun
- type CheckRunResult
- type CheckRunStatus
- type CheckSuite
- type CheckSuiteExpandParameter
- type CheckSuiteRef
- type CheckSuiteRequest
- type CheckType
- type Client
- type ClientImpl
- func (client *ClientImpl) AddCheckConfiguration(ctx context.Context, args AddCheckConfigurationArgs) (*CheckConfiguration, error)
- func (client *ClientImpl) DeleteCheckConfiguration(ctx context.Context, args DeleteCheckConfigurationArgs) error
- func (client *ClientImpl) EvaluateCheckSuite(ctx context.Context, args EvaluateCheckSuiteArgs) (*CheckSuite, error)
- func (client *ClientImpl) GetCheckConfiguration(ctx context.Context, args GetCheckConfigurationArgs) (*CheckConfiguration, error)
- func (client *ClientImpl) GetCheckConfigurationsOnResource(ctx context.Context, args GetCheckConfigurationsOnResourceArgs) (*[]CheckConfiguration, error)
- func (client *ClientImpl) GetCheckSuite(ctx context.Context, args GetCheckSuiteArgs) (*CheckSuite, error)
- func (client *ClientImpl) QueryCheckConfigurationsOnResources(ctx context.Context, args QueryCheckConfigurationsOnResourcesArgs) (*[]CheckConfiguration, error)
- func (client *ClientImpl) UpdateCheckConfiguration(ctx context.Context, args UpdateCheckConfigurationArgs) (*CheckConfiguration, error)
- type DeleteCheckConfigurationArgs
- type EvaluateCheckSuiteArgs
- type GenericCheckConfiguration
- type GetCheckConfigurationArgs
- type GetCheckConfigurationsOnResourceArgs
- type GetCheckSuiteArgs
- type QueryCheckConfigurationsOnResourcesArgs
- type Resource
- type TaskCheckConfiguration
- type TimeZone
- type UpdateCheckConfigurationArgs
Constants ¶
This section is empty.
Variables ¶
var CheckConfigurationExpandParameterValues = checkConfigurationExpandParameterValuesType{
None: "none",
Settings: "settings",
}
var CheckRunStatusValues = checkRunStatusValuesType{
None: "none",
Queued: "queued",
Running: "running",
Approved: "approved",
Rejected: "rejected",
Canceled: "canceled",
TimedOut: "timedOut",
Failed: "failed",
Completed: "completed",
All: "all",
}
var CheckSuiteExpandParameterValues = checkSuiteExpandParameterValuesType{
None: "none",
Resources: "resources",
}
var ResourceAreaId, _ = uuid.Parse("4a933897-0488-45af-bd82-6fd3ad33f46a")
Functions ¶
This section is empty.
Types ¶
type AddCheckConfigurationArgs ¶
type AddCheckConfigurationArgs struct {
// (required)
Configuration *CheckConfiguration
// (required) Project ID or project name
Project *string
}
Arguments for the AddCheckConfiguration function
type ApprovalCheckConfiguration ¶
type ApprovalCheckConfiguration struct {
// Check configuration id.
Id *int `json:"id,omitempty"`
// Resource on which check get configured.
Resource *Resource `json:"resource,omitempty"`
// Check configuration type
Type *CheckType `json:"type,omitempty"`
// The URL from which one can fetch the configured check.
Url *string `json:"url,omitempty"`
// Reference links.
Links interface{} `json:"_links,omitempty"`
// Identity of person who configured check.
CreatedBy *webapi.IdentityRef `json:"createdBy,omitempty"`
// Time when check got configured.
CreatedOn *azuredevops.Time `json:"createdOn,omitempty"`
// Identity of person who modified the configured check.
ModifiedBy *webapi.IdentityRef `json:"modifiedBy,omitempty"`
// Time when configured check was modified.
ModifiedOn *azuredevops.Time `json:"modifiedOn,omitempty"`
// Timeout in minutes for the check.
Timeout *int `json:"timeout,omitempty"`
// Settings for the approval check configuration.
Settings *pipelinesapproval.ApprovalConfigSettings `json:"settings,omitempty"`
}
type CheckConfiguration ¶
type CheckConfiguration struct {
// Check configuration id.
Id *int `json:"id,omitempty"`
// Resource on which check get configured.
Resource *Resource `json:"resource,omitempty"`
// Check configuration type
Type *CheckType `json:"type,omitempty"`
// The URL from which one can fetch the configured check.
Url *string `json:"url,omitempty"`
// Reference links.
Links interface{} `json:"_links,omitempty"`
// Identity of person who configured check.
CreatedBy *webapi.IdentityRef `json:"createdBy,omitempty"`
// Time when check got configured.
CreatedOn *azuredevops.Time `json:"createdOn,omitempty"`
// Identity of person who modified the configured check.
ModifiedBy *webapi.IdentityRef `json:"modifiedBy,omitempty"`
// Time when configured check was modified.
ModifiedOn *azuredevops.Time `json:"modifiedOn,omitempty"`
// Timeout in minutes for the check.
Timeout *int `json:"timeout,omitempty"`
}
type CheckConfigurationData ¶
type CheckConfigurationData struct {
// Check configuration of the check.
CheckConfiguration *CheckConfiguration `json:"checkConfiguration,omitempty"`
// Definition Ref Id of the particular check.
DefinitionRefId *uuid.UUID `json:"definitionRefId,omitempty"`
}
type CheckConfigurationRef ¶
type CheckConfigurationRef struct {
// Check configuration id.
Id *int `json:"id,omitempty"`
// Resource on which check get configured.
Resource *Resource `json:"resource,omitempty"`
// Check configuration type
Type *CheckType `json:"type,omitempty"`
// The URL from which one can fetch the configured check.
Url *string `json:"url,omitempty"`
}
type CheckData ¶
type CheckData struct {
// List of check configuration data
CheckConfigurationDataList *[]CheckConfigurationData `json:"checkConfigurationDataList,omitempty"`
// List of check definitions
CheckDefinitions *[]CheckDefinitionData `json:"checkDefinitions,omitempty"`
// List of time zones.
TimeZoneList *[]TimeZone `json:"timeZoneList,omitempty"`
}
type CheckDefinitionData ¶
type CheckDefinitionData struct {
// Flag to allow multiple configurations of a particular check on a resource.
AllowMultipleConfigurations *bool `json:"allowMultipleConfigurations,omitempty"`
// Details about the check
CheckDefinition interface{} `json:"checkDefinition,omitempty"`
// Check DefinitionRef Id
DefinitionRefId *uuid.UUID `json:"definitionRefId,omitempty"`
// Description about the check
Description *string `json:"description,omitempty"`
// Icon for the check
Icon *CheckIcon `json:"icon,omitempty"`
// Name of the check
Name *string `json:"name,omitempty"`
// Check UI contribution Dependencies
UiContributionDependencies *[]string `json:"uiContributionDependencies,omitempty"`
// Check UI contribution Type
UiContributionType *string `json:"uiContributionType,omitempty"`
}
type CheckRun ¶
type CheckRun struct {
ResultMessage *string `json:"resultMessage,omitempty"`
Status *CheckRunStatus `json:"status,omitempty"`
CheckConfigurationRef *CheckConfigurationRef `json:"checkConfigurationRef,omitempty"`
CompletedDate *azuredevops.Time `json:"completedDate,omitempty"`
CreatedDate *azuredevops.Time `json:"createdDate,omitempty"`
Id *uuid.UUID `json:"id,omitempty"`
}
type CheckRunResult ¶
type CheckRunResult struct {
ResultMessage *string `json:"resultMessage,omitempty"`
Status *CheckRunStatus `json:"status,omitempty"`
}
type CheckSuite ¶
type CheckSuite struct {
// Evaluation context for the check suite request
Context interface{} `json:"context,omitempty"`
// Unique suite id generated by the pipeline orchestrator for the pipeline check runs request on the list of resources Pipeline orchestrator will used this identifier to map the check requests on a stage
Id *uuid.UUID `json:"id,omitempty"`
// Reference links.
Links interface{} `json:"_links,omitempty"`
// List of check runs associated with the given check suite request.
CheckRuns *[]CheckRun `json:"checkRuns,omitempty"`
// Completed date of the given check suite request
CompletedDate *azuredevops.Time `json:"completedDate,omitempty"`
// Optional message for the given check suite request
Message *string `json:"message,omitempty"`
// Overall check runs status for the given suite request. This is check suite status
Status *CheckRunStatus `json:"status,omitempty"`
}
type CheckSuiteRef ¶
type CheckSuiteRef struct {
// Evaluation context for the check suite request
Context interface{} `json:"context,omitempty"`
// Unique suite id generated by the pipeline orchestrator for the pipeline check runs request on the list of resources Pipeline orchestrator will used this identifier to map the check requests on a stage
Id *uuid.UUID `json:"id,omitempty"`
}
type CheckSuiteRequest ¶
type Client ¶
type Client interface {
// [Preview API] Add a check configuration
AddCheckConfiguration(context.Context, AddCheckConfigurationArgs) (*CheckConfiguration, error)
// [Preview API]
DeleteCheckConfiguration(context.Context, DeleteCheckConfigurationArgs) error
// [Preview API]
EvaluateCheckSuite(context.Context, EvaluateCheckSuiteArgs) (*CheckSuite, error)
// [Preview API] Get Check configuration by Id
GetCheckConfiguration(context.Context, GetCheckConfigurationArgs) (*CheckConfiguration, error)
// [Preview API] Get Check configuration by resource type and id
GetCheckConfigurationsOnResource(context.Context, GetCheckConfigurationsOnResourceArgs) (*[]CheckConfiguration, error)
// [Preview API]
GetCheckSuite(context.Context, GetCheckSuiteArgs) (*CheckSuite, error)
// [Preview API] Get check configurations for multiple resources by resource type and id.
QueryCheckConfigurationsOnResources(context.Context, QueryCheckConfigurationsOnResourcesArgs) (*[]CheckConfiguration, error)
// [Preview API] Update check configuration
UpdateCheckConfiguration(context.Context, UpdateCheckConfigurationArgs) (*CheckConfiguration, error)
}
func NewClient ¶
func NewClient(ctx context.Context, connection *azuredevops.Connection) (Client, error)
type ClientImpl ¶
type ClientImpl struct {
Client azuredevops.Client
}
func (*ClientImpl) AddCheckConfiguration ¶
func (client *ClientImpl) AddCheckConfiguration(ctx context.Context, args AddCheckConfigurationArgs) (*CheckConfiguration, error)
[Preview API] Add a check configuration
func (*ClientImpl) DeleteCheckConfiguration ¶
func (client *ClientImpl) DeleteCheckConfiguration(ctx context.Context, args DeleteCheckConfigurationArgs) error
[Preview API]
func (*ClientImpl) EvaluateCheckSuite ¶
func (client *ClientImpl) EvaluateCheckSuite(ctx context.Context, args EvaluateCheckSuiteArgs) (*CheckSuite, error)
[Preview API]
func (*ClientImpl) GetCheckConfiguration ¶
func (client *ClientImpl) GetCheckConfiguration(ctx context.Context, args GetCheckConfigurationArgs) (*CheckConfiguration, error)
[Preview API] Get Check configuration by Id
func (*ClientImpl) GetCheckConfigurationsOnResource ¶
func (client *ClientImpl) GetCheckConfigurationsOnResource(ctx context.Context, args GetCheckConfigurationsOnResourceArgs) (*[]CheckConfiguration, error)
[Preview API] Get Check configuration by resource type and id
func (*ClientImpl) GetCheckSuite ¶
func (client *ClientImpl) GetCheckSuite(ctx context.Context, args GetCheckSuiteArgs) (*CheckSuite, error)
[Preview API]
func (*ClientImpl) QueryCheckConfigurationsOnResources ¶
func (client *ClientImpl) QueryCheckConfigurationsOnResources(ctx context.Context, args QueryCheckConfigurationsOnResourcesArgs) (*[]CheckConfiguration, error)
[Preview API] Get check configurations for multiple resources by resource type and id.
func (*ClientImpl) UpdateCheckConfiguration ¶
func (client *ClientImpl) UpdateCheckConfiguration(ctx context.Context, args UpdateCheckConfigurationArgs) (*CheckConfiguration, error)
[Preview API] Update check configuration
type DeleteCheckConfigurationArgs ¶
type DeleteCheckConfigurationArgs struct {
// (required) Project ID or project name
Project *string
// (required)
Id *int
}
Arguments for the DeleteCheckConfiguration function
type EvaluateCheckSuiteArgs ¶
type EvaluateCheckSuiteArgs struct {
// (required)
Request *CheckSuiteRequest
// (required) Project ID or project name
Project *string
// (optional)
Expand *CheckSuiteExpandParameter
}
Arguments for the EvaluateCheckSuite function
type GenericCheckConfiguration ¶
type GenericCheckConfiguration struct {
// Check configuration id.
Id *int `json:"id,omitempty"`
// Resource on which check get configured.
Resource *Resource `json:"resource,omitempty"`
// Check configuration type
Type *CheckType `json:"type,omitempty"`
// The URL from which one can fetch the configured check.
Url *string `json:"url,omitempty"`
// Reference links.
Links interface{} `json:"_links,omitempty"`
// Identity of person who configured check.
CreatedBy *webapi.IdentityRef `json:"createdBy,omitempty"`
// Time when check got configured.
CreatedOn *azuredevops.Time `json:"createdOn,omitempty"`
// Identity of person who modified the configured check.
ModifiedBy *webapi.IdentityRef `json:"modifiedBy,omitempty"`
// Time when configured check was modified.
ModifiedOn *azuredevops.Time `json:"modifiedOn,omitempty"`
// Timeout in minutes for the check.
Timeout *int `json:"timeout,omitempty"`
// Settings for the generic check configuration.
Settings interface{} `json:"settings,omitempty"`
}
type GetCheckConfigurationArgs ¶
type GetCheckConfigurationArgs struct {
// (required) Project ID or project name
Project *string
// (required)
Id *int
// (optional)
Expand *CheckConfigurationExpandParameter
}
Arguments for the GetCheckConfiguration function
type GetCheckConfigurationsOnResourceArgs ¶
type GetCheckConfigurationsOnResourceArgs struct {
// (required) Project ID or project name
Project *string
// (optional) resource type
ResourceType *string
// (optional) resource id
ResourceId *string
// (optional)
Expand *CheckConfigurationExpandParameter
}
Arguments for the GetCheckConfigurationsOnResource function
type GetCheckSuiteArgs ¶
type GetCheckSuiteArgs struct {
// (required) Project ID or project name
Project *string
// (required)
CheckSuiteId *uuid.UUID
// (optional)
Expand *CheckSuiteExpandParameter
}
Arguments for the GetCheckSuite function
type QueryCheckConfigurationsOnResourcesArgs ¶
type QueryCheckConfigurationsOnResourcesArgs struct {
// (required) List of resources.
Resources *[]Resource
// (required) Project ID or project name
Project *string
// (optional) The properties that should be expanded in the list of check configurations.
Expand *CheckConfigurationExpandParameter
}
Arguments for the QueryCheckConfigurationsOnResources function
type TaskCheckConfiguration ¶
type TaskCheckConfiguration struct {
// Check configuration id.
Id *int `json:"id,omitempty"`
// Resource on which check get configured.
Resource *Resource `json:"resource,omitempty"`
// Check configuration type
Type *CheckType `json:"type,omitempty"`
// The URL from which one can fetch the configured check.
Url *string `json:"url,omitempty"`
// Reference links.
Links interface{} `json:"_links,omitempty"`
// Identity of person who configured check.
CreatedBy *webapi.IdentityRef `json:"createdBy,omitempty"`
// Time when check got configured.
CreatedOn *azuredevops.Time `json:"createdOn,omitempty"`
// Identity of person who modified the configured check.
ModifiedBy *webapi.IdentityRef `json:"modifiedBy,omitempty"`
// Time when configured check was modified.
ModifiedOn *azuredevops.Time `json:"modifiedOn,omitempty"`
// Timeout in minutes for the check.
Timeout *int `json:"timeout,omitempty"`
// Settings for the task check configuration.
Settings *pipelinestaskcheck.TaskCheckConfig `json:"settings,omitempty"`
}
type UpdateCheckConfigurationArgs ¶
type UpdateCheckConfigurationArgs struct {
// (required) check configuration
Configuration *CheckConfiguration
// (required) Project ID or project name
Project *string
// (required) check configuration id
Id *int
}
Arguments for the UpdateCheckConfiguration function